@@ -75,7 +75,7 @@ class WrappedNode(nodes.Node):
         super().__init__()
 
     def action(self) -> None:
-        """Call the wrapped function and put it's return in the ``output`` connector."""
+        """Call the wrapped function and put it's return into the ``output`` connector."""
 
         for data in self.input.iter_get():
             self.output.put(self._func(data))
